@@ -1,6 +1,9 @@
       block data cblkEvhnp
 #include  "Zevhnp.h"
-
+c            currently usable models
+      data RegMdls/'dpmjet3', 'nexus2', 'fritiof7.02', 'fritiof1.6',
+     *             'gheisha', 'nucrin', 'ad-hoc', 'inclusive'/
+      
        data  
      * Cepic0 /0.00d0/ , 
      * Cekaon /0.d0/ ,
@@ -20,7 +23,7 @@
      * SucPw /1.5/,
      * MulLow /1/,      ! old one is 0. bef. v.5.0
      * LundPara /1, 2, 0, 0, 1, 5*0/,
-     * IntModel /'int1'/ ,
+     * IntModel /'"dpmjet3" 1.d8'/ ,
      * InclusiveFile /'../../Contrib/Inclusive/xdist.d'/ ,
      * Efermi /10.e-3/
        data 
