@@ -21,6 +21,10 @@ c
 #include  "Zheavyv.h"
 #include  "Zevhnp.h"
 #include  "Zevhnv.h"
+c///////////
+c        logical deb
+c        common/cdebug/ deb
+c//////////
 c
         external cblkHeavy
 c
@@ -66,7 +70,9 @@ c
 c                                          
 c        if(IntModel .eq. 'int2' .and.
 c     *      ( pj.code .eq. ktriton .or. pj.code .eq. kdeut) ) then
-        if( ActiveMdl .eq. 'dpmjet3' ) then
+        if( ActiveMdl .eq. 'dpmjet3' .and.
+     *    (pj.fm.p(4) - pj.mass)/pj.subcode .gt. 5.1) then
+              !   avoid recursive call from cdpmjet
            call cdpmjet(pj, ia, iz, a, ntp)
         elseif(ActiveMdl .eq. 'gheisha' .and.
      *        pj.code .eq. kgnuc  .and. (pj.subcode .eq. 2 .or.
@@ -195,9 +201,13 @@ c         get heavy group index from the incident charge
       ihg=Charge2heavyG(pj.charge)
 
 c          # of nucleons
-      mno=HeavyG2massN(ihg)
+c      mno=HeavyG2massN(ihg)
+      mno = pj.subcode
 c       z 
-      hchg=HeavyG2charge(ihg)
+c      hchg=HeavyG2charge(ihg)
+
+       hchg=pj.charge
+
 c       t.e  energy per nucleon
       epn=pj.fm.p(4)/mno
 c         margin for mass no. conservation (for first trial)
