@@ -45,6 +45,9 @@ c
           integer ia, iz, leng, kgetenv
           logical lroots, cms, xbyp
           integer dcy, i
+c////////////
+          real*8  tgtA, tgtZ, xs
+c/////////////
 
 c
           record /fmom/ rest
@@ -168,6 +171,7 @@ c                        the last / is needed.
              endif
           endif
 
+
 c              This is to form  Cmsp
           call chncol(pj2, tg, a, ntp, icon)
 
@@ -212,6 +216,21 @@ c             fix model by seeing the proj. energy.
              else
                 call cheavyInt(pj, ia, iz, a, ntp0)
              endif
+c/////////////
+             tgtA = ia
+             tgtZ = iz
+             call cxsecGheisha(pj, tgtA, tgtZ, xs)
+            write(0,*) xs
+c
+c
+            call ctotx(pj, tgtA,  xs)
+
+            write(0,*) xs
+            call cprotonAXsec(tgtA, pj.fm.p(4)-pj.mass, xs)
+            write(0,*) xs
+
+c////////////
+
 
 c                decay sigma etc if requested
              call mydecay(a, ntp0,  ntp)
