@@ -1,4 +1,4 @@
-      subroutine ciniTracking
+      subroutine ciniTracking( incident )
 c          this is called after primary is fixed.
       implicit none
 
@@ -14,14 +14,16 @@ c          this is called after primary is fixed.
 #include "Zearth.h"
 
       external cxyz2prim, cxyz2det
-      integer klena, leng
+      integer klena, leng, icon
       real*8  zAngleSave, r1, r2, cosx, lengx
       real*8 clenbetween2h, cnewcos
-      character*70 tracefile
+      character*80 tracefile
+      record /track/ incident
       data zAngleSave/-1.d30/
       save zAngleSave
 
-      Zfirst = 0.
+
+      Zfirst.pos.depth = 0.
       Zsave = -1.d30
 #if LABELING > 0
       Labelcounter = 0
@@ -44,7 +46,8 @@ c            default trace output is requested. Open disk file
          write(tracefile, *) TraceDir(1:klena(TraceDir))//'/trace',
      *         EventNo
          call kseblk(tracefile, ' ', leng)
-         open(TraceDev, file=tracefile(1:leng), form='formatted')
+         call copenfw(TraceDev, tracefile(1:leng), icon)
+         if(icon  .ne. 0) stop
       elseif(Trace .gt. 60 .and. Trace .lt. 100 .or.
      *       Trace .gt. 160 .and. Trace .lt. 200) then
          call cputCerenkovS     ! cerenkov output header for each event
@@ -82,6 +85,14 @@ c         for lenth <--> thickness conversion.  make table for that
      *     LenTbl, HeightTbl, CosTbl,  ThickTbl, maxl2t, NumStep)
          zAngleSave = AngleAtObsCopy.r(3)
       endif
+c          fix B at the starting point
+      if( HowGeomag .le. 2 .or. HowGeomag .eq. 31 ) then
+         call cgeomag(YearOfGeomag, incident.pos.xyz, Mag, icon)
+         call ctransMagTo('xyz', incident.pos.xyz,  Mag, Mag)
+      else
+         Mag = MagfieldXYZ
+      endif
+
       end
 c     --------- compute primary system, x,y,z.  
 c               The deepest detector is the reference.
@@ -161,7 +172,20 @@ c         inquire the first interaction depth
 #include "Ztrackv.h"
       real*8 depth   ! output. to get the first I.D
       
-      depth = Zfirst   ! vertical depth
+      depth = Zfirst.pos.depth   ! vertical depth
+      end
+c      **************************
+      subroutine cqFirstIPI(ptrack)
+c         inquire the complete first interaction point info. 
+c         as a track of the primary.
+      implicit none
+
+#include "Ztrack.h"
+#include "Ztrackv.h"
+      record /track/ ptrack   ! output.    if ptrack.pos.depth=0.
+                              !  no interaction has been occurred
+      
+      ptrack = Zfirst
       end
 
 c --------------------------------
@@ -213,8 +237,12 @@ c
 
 
 c          energy / nucleon for heavy
-      if(IncidentCopy.p.code .ge. kdeut .and.
+      if(IncidentCopy.p.code .eq. kgnuc) then
+         ergpn =
+     *        IncidentCopy.p.fm.p(4)/IncidentCopy.p.subcode
+      elseif(IncidentCopy.p.code .ge. kalfa .and.
      *     IncidentCopy.p.code .le.  khvymax) then
+c           will  not come here
          ergpn =
      *        IncidentCopy.p.fm.p(4)/Code2massN(IncidentCopy.p.code)
       else
