@@ -85,6 +85,7 @@ c                it include elastic scattering;
 c                so we use different cross-sections
          call cxsecGheisha(TrackBefMove.p, 
      *        TargetMassN, TargetAtomicN, xs)
+
          mfp = toabn*TargetMassN/xs ! in kg/m2
 c               sample interaction length
          call rndc(u)
@@ -92,7 +93,11 @@ c               sample interaction length
       elseif(useInt2 .and. ActiveMdl .eq. 'dpmjet3') then
 c          use total X-section
 
-         call ctotx(TrackBefMove.p, TargetMassN,  xs)
+cccc         call ctotx(TrackBefMove.p, TargetMassN,  xs)
+c              borrow gheisha cross-section for total 
+         call cxsecGheisha(TrackBefMove.p, 
+     *        TargetMassN, TargetAtomicN, xs)
+
          mfp = toabn*TargetMassN/xs ! in kg/m2
 c               sample interaction length
          call rndc(u)
