@@ -40,9 +40,13 @@ c
 #include  "Zobsv.h"
 
        record /coord/a, b
+       record /coord/temp
 
-       call cscalerProd(a, Xprimary, b.r(1))
-       call cscalerProd(a, Yprimary, b.r(2))
-       call cscalerProd(a, Zprimary, b.r(3))
+c          b can be a
+
+       call cscalerProd(a, Xprimary, temp.r(1))
+       call cscalerProd(a, Yprimary, temp.r(2))
+       call cscalerProd(a, Zprimary, temp.r(3))
+       b = temp
        b.sys = 'prim'
        end
